source('library.R')

load('../data/private/xbox.RData')

# read in the 2008 and 2012 exit poll data
exit_poll_2008 <- data.frame(as.data.set(spss.portable.file('../data/private/usmi2008-natelec.por')))
exit_poll_2012 <- data.frame(as.data.set(spss.system.file('../data/private/national12_review.sav')))

convert_state <- function(state) {
	state <- str_trim(tolower(state))
	old <- tolower(c(state.name, 'district of columbia'))
	new <- c(state.abb, 'DC')

	abbrv <- mapvalues(state, from=old, to=new, warn_missing = FALSE)
	abbrv
}

convert_race <- function(race) {
	old <- c("White", "Black", "Hispanic/Latino", "Asian", "Other")
	new <- c('white', 'black', 'hispanic', 'other', 'other')
	race <- mapvalues(as.character(race), from=old, to=new, warn_missing = FALSE)
	race
}

convert_party_id <- function(party_id) {
	old <- c("Democrat", "Republican", "Independent/Something else")
	new <- c('democrat', 'republican', 'other')
	party_id <- mapvalues(as.character(party_id), from=old, to=new, warn_missing = FALSE)
	party_id
}

convert_education <- function(edu) {
	old <- c("Did not complete high school", "High school graduate", "Some college or associate degree",
		"College graduate", "Postgraduate study")
	old <- c(old, c('No high school diploma', 'High school graduate', 'Some college/assoc. degree',
		'College graduate', 'Postgraduate study'))
	new <- c("didn\'t graduate from HS", "high school graduate", "some college",
		"college graduate", "college graduate")
	new <- c(new, new)
	edu <- mapvalues(as.character(edu), from=old, to=new, warn_missing = FALSE)
	edu
}

convert_vote_2004 <- function(vote) {
	vote <- tolower(vote)
	old <- c('did not vote', 'someone else', 'omit')
	new <- c('did not vote in 2004', 'other', NA)
	vote <- mapvalues(vote, from=old, to=new, warn_missing = FALSE)
	vote
}

convert_vote_2008 <- function(vote) {
	vote <- tolower(vote)
	old <- c('john mccain', 'did not vote')
	new <- c('john mcCain', 'did not vote in 2008')
	vote <- mapvalues(vote, from=old, to=new, warn_missing = FALSE)
	vote
}

convert_vote_2012 <- function(vote) {
	vote <- tolower(vote)
	old <- c('did not vote')
	new <- c('did not vote in 2012')
	vote <- mapvalues(vote, from=old, to=new, warn_missing = FALSE)
	vote
}

convert_age <- function(age) {
	age <- mapvalues(as.character(age), '45-65', '45-64', warn_missing = FALSE)
	age
}

exit_poll_2008 <- transmute(exit_poll_2008,
	weight,
	state = factor(convert_state(stanum), levels=levels(user_demo$state)),
	state_contestedness = factor(contestedness(state)),
	sex = factor(tolower(sex), levels=levels(user_demo$sex)),
	race = factor(convert_race(race), levels=levels(user_demo$race)),
	age = factor(convert_age(age), levels=levels(user_demo$age)),
	education = factor(convert_education(educ), levels=levels(user_demo$education)),
	party_id = factor(convert_party_id(party), levels=levels(user_demo$party_id)),
	ideology = factor(tolower(phil3), levels=levels(user_demo$ideology)),
	vote_2004 = factor(convert_vote_2004(vote2004), levels=c('george w. bush','john kerry', 'other','did not vote in 2004')),
	vote_2008 = factor(convert_vote_2008(prsus08), levels=levels(user_demo$vote_2008))
)

exit_poll_2012 <- transmute(exit_poll_2012,
	weight,
	state = factor(convert_state(stanum), levels=levels(user_demo$state)),
	state_contestedness = factor(contestedness(state)),
	sex = factor(tolower(sex), levels=levels(user_demo$sex)),
	race = factor(convert_race(race), levels=levels(user_demo$race)),
	age = factor(convert_age(age), levels=levels(user_demo$age)),
	education = factor(convert_education(educ10), levels=levels(user_demo$education)),
	party_id = factor(convert_party_id(party), levels=levels(user_demo$party_id)),
	ideology = factor(tolower(phil3), levels=levels(user_demo$ideology)),
	vote_2012 = factor(convert_vote_2012(pres), levels=c("barack obama", "mitt romney", "other"))
)

save(file="../data/private/exit_poll.RData", exit_poll_2008, exit_poll_2012)

